kss_client_action_alias
open | /demo/kss_client_action_alias.html |
click | button_1 |
waitForValue | button_2 | RESET ME
verifyValue | button_3 | RESET ME TOO
click | button_2 |
waitForValue | button_2 | Watch me
click | button_3 |
waitForValue | button_3 | Watch me
click | button_4 |
waitForValue | button_5 | RESET ME
verifyValue | button_6 | RESET ME TOO
click | button_5 |
waitForValue | button_5 | Watch me
click | button_6 |
waitForValue | button_6 | Watch me
click | button_7 |
waitForValue | button_8 | RESET ME
verifyValue | button_9 | RESET ME TOO
verifyValue | button_6 | Watch me
click | button_8 |
waitForValue | button_8 | Watch me
click | button_9 |
waitForValue | button_9 | Watch me